@@ -1,7 +1,7 @@
 from typing import Dict
 
 from apispec import APISpec
-from flask import current_app, Response
+from flask import current_app, Response as FlaskResponse
 from flask_restful import Resource
 
 from automd.decorators import automd
@@ -10,10 +10,10 @@ from automd.keys import AutoMDKeys
 from automd.templates.openapi import generate_template_from_dict
 
 
-class OpenMDHTML(Resource):
-    @automd(summary='OpenAPI HTML Documentation Endpoint',
-            description='Returns the OpenAPI HTML',
-            tags=[{"name": "AutoMD"}])
+class AutoMDHTML(Resource):
+    @automd(summary="OpenAPI HTML Documentation Endpoint",
+            description="Returns the OpenAPI HTML",
+            tags=["AutoMD"])
     def get(self) -> str:
         auto_app: AutoMD = current_app.config[AutoMDKeys.config.value].auto_md
 
@@ -21,4 +21,4 @@ class OpenMDHTML(Resource):
 
         ret: Dict = automd_spec.to_dict()
 
-        return Response(generate_template_from_dict(ret), mimetype='text/html')
+        return FlaskResponse(generate_template_from_dict(ret), mimetype="text/html")
