@@ -1,5 +1,3 @@
-import logging
-
 from typing import Dict
 
 from apispec import APISpec
@@ -10,13 +8,11 @@ from automd.decorators import automd
 from automd.automd import AutoMD
 from automd.keys import AutoMDKeys
 
-logger = logging.getLogger(__name__)
-
 
 class OpenAPISpecJSON(Resource):
     @automd(summary="OpenAPI JSON Documentation Endpoint",
             description="Returns the OpenAPI Spec in JSON format",
-            tags=[{"name": "AutoMD"}])
+            tags=["AutoMD"])
     def get(self) -> Dict:
         auto_app: AutoMD = current_app.config[AutoMDKeys.config.value].auto_md
 
@@ -30,7 +26,7 @@ class OpenAPISpecJSON(Resource):
 class OpenAPISpecYAML(Resource):
     @automd(summary="OpenAPI Yaml Documentation Endpoint",
             description="Returns the OpenAPI Spec in Yaml format",
-            tags=[{"name": "AutoMD"}])
+            tags=["AutoMD"])
     def get(self) -> str:
         auto_app: AutoMD = current_app.config[AutoMDKeys.config.value].auto_md
 
